package com.bonus.sgzb.machine.mapper;

import com.bonus.sgzb.machine.vo.MaLabelBindVO;

import java.util.List;

/**
 * 机具设备标签ma_label_bind(MaLabelBind)表数据库访问层
 *
 * @author makejava
 * @since 2023-11-28 16:37:45
 */
public interface MaLabelBindMapper {

    /**
     * 查询标签绑定管理列表
     * @param typeName
     * @return
     */
    List<MaLabelBindVO> selectMaLabelList(String typeName);

    /**
     * 批量绑定
     * @param labelIds
     * @return
     */
    int updateBind(Long[] labelIds);

    /**
     * 标签解绑
     * @param labelId
     * @return
     */
    int updateNoBind(Long labelId);

    /**
     * 验证类型名称唯一性
     * @param typeName
     * @return
     */
    MaLabelBindVO checkLabelNameUnique(String typeName);

    /**
     * 新增标签类型数据
     * @param maLabelBindVO
     */
    void insertLabel(MaLabelBindVO maLabelBindVO);

    /**
     * 新增类型
     * @param maLabelBindVO
     */
    void insertType(MaLabelBindVO maLabelBindVO);

    /**
     * 更新标签类型数据
     * @param maLabelBindVO
     */
    void updateMaLabel(MaLabelBindVO maLabelBindVO);

    /**
     * 修改类型
     * @param maLabelBindVO
     */
    void updateMaType(MaLabelBindVO maLabelBindVO);
}

